#property copyright "Public domain software by Ralph Ronnquist"
#property link      ""

// Tells the broker's current time zone
extern int timezone=0;
extern int magic = 96;

extern int SAMPLE_HOUR = 7;
extern int EXPIRES = 6;
extern int OP = 40;
extern int TP = 5;
extern int SL = 20;
extern double lots = 1.0;

int state = 0;

int init()
{
    return( 0 );
}

int deinit()
{
    return( 0 );
}

int start()
{
    // Track time of first tick after that the EA is dropped onto the chart.
    static datetime first_tick = 0;
    if ( first_tick == 0 ) first_tick = TimeCurrent();

    int i;
    double price;
    bool some_open = false;

    // Review open trades in order to apply the closing condition. It also determines
    // whether there are any open trades, in which case no more trades should be opened.
    for ( i = OrdersTotal() - 1; i >=0; i-- ) {
        if ( ! OrderSelect( i, SELECT_BY_POS, MODE_TRADES ) )
            continue;
        if ( magic != 0 && OrderMagicNumber() != magic )
            continue;
        if ( OrderSymbol() != Symbol() )
            continue;
        if ( OrderType() == OP_BUY ) {
            if ( Bid < OrderOpenPrice() + TP * Point && Bid > OrderOpenPrice() - SL * Point ) {
                some_open = true;
                continue;
            }
            price = Bid;
        } else if ( OrderType() == OP_SELL ) {
            if ( Ask > OrderOpenPrice() - TP * Point && Ask < OrderOpenPrice() + SL * Point ) {
                some_open = true;
                continue;
            }
            price = Ask;
        }
        if ( ! OrderClose( OrderTicket(), OrderLots(), price, Yellow ) )
            some_open = true;
    }
    if ( some_open )
        return( 0 );

    // Determine the date stamp for the sample
    // gmt_day is the current date at GMT time
    // sample_time is the time stamp the broker has for the selected GMT sample hour
    string gmt_day = TimeToStr( TimeCurrent() - timezone * 3600, TIME_DATE );
    datetime sample_time = StrToTime( gmt_day ) + ( SAMPLE_HOUR + timezone ) * 3600 ;
    
    datetime last_sample = sample_time;
    if ( last_sample > TimeCurrent() )
        last_sample -= 86400;

    // Review account history for a trade after the sample time, so as to avoid
    // a second one.
    for ( i = OrdersHistoryTotal() - 1; i >=0; i-- ) {
        if ( ! OrderSelect( i, SELECT_BY_POS, MODE_HISTORY ) )
            continue;
        if ( magic != 0 && OrderMagicNumber() != magic )
            continue;
        if ( OrderSymbol() != Symbol() )
            continue;
        if ( OrderOpenTime() >= last_sample ) {
            return( 0 );
        }
    }

    // Avoid trading at today's sample time if  it is before the first EA tick time
    if ( sample_time < first_tick ) return( 0 );

    // Limit the enabling period to be EXPIRES hours after sample SAMPLE_HOUR each day.
    if ( TimeCurrent() < sample_time ) return( 0 ); // Too early
    if ( TimeCurrent() >= sample_time + EXPIRES * 3600 ) return( 0 ); // Too late

    
    double sample_price =
        iOpen( Symbol(), PERIOD_H1, iBarShift( Symbol(), PERIOD_H1, sample_time, true ) );

    // Check for opening condition
    int type = -1;
    if ( Ask >= sample_price + OP * Point ) {
        type = OP_BUY;
        price = Ask;
    } else if ( Bid <= sample_price - OP * Point ) {
        type = OP_SELL;
        price = Bid;
    } else {
        return( 0 );
    }
    
    OrderSend( Symbol(), type, lots, price, 0, 0, 0, "", magic, 0, CLR_NONE );
    return(0);
}

